==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebColumnMovingEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingEndEventArgsDetailDescriptionMetadata } from "./WebColumnMovingEndEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDescription } from "./WebColumnMovingEndEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEndEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEndEventArgsDescriptionMetadata.c(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingEndEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingEndEventArgsDescriptionMetadata.b(a);
            a.ad("WebColumnMovingEndEventArgs", () => new WebColumnMovingEndEventArgsDescription());
            a.ac("WebColumnMovingEndEventArgs", WebColumnMovingEndEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingEndEventArgsDescriptionMetadata.$t = markType(WebColumnMovingEndEventArgsDescriptionMetadata, 'WebColumnMovingEndEventArgsDescriptionMetadata');
    WebColumnMovingEndEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebColumnMovingEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingEndEventArgsDetailDescriptionMetadata } from "./WebColumnMovingEndEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDescription } from "./WebColumnMovingEndEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEndEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEndEventArgsDescriptionMetadata.c(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnMovingEndEventArgsDescriptionMetadata.a);
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingEndEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingEndEventArgsDescriptionMetadata.b(a);
            a.ae("WebColumnMovingEndEventArgs", () => new WebColumnMovingEndEventArgsDescription());
            a.ad("WebColumnMovingEndEventArgs", WebColumnMovingEndEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingEndEventArgsDescriptionMetadata.$t = markType(WebColumnMovingEndEventArgsDescriptionMetadata, 'WebColumnMovingEndEventArgsDescriptionMetadata');
    WebColumnMovingEndEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDescriptionMetadata;
})();
